.. role:: hidden
    :class: hidden-section

ax.core
===================================

.. automodule:: ax.core
.. currentmodule:: ax.core


Core Classes
-------------

`AbstractData`
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.abstract_data
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

`Arm`
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.arm
    :members:
    :undoc-members:
    :show-inheritance:

`BaseTrial`
~~~~~~~~~~~

.. automodule:: ax.core.base_trial
    :members:
    :undoc-members:
    :show-inheritance:

`BatchTrial`
~~~~~~~~~~~~~

.. automodule:: ax.core.batch_trial
    :members:
    :undoc-members:
    :show-inheritance:

`Data`
~~~~~~~~~~

.. automodule:: ax.core.data
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

`Experiment`
~~~~~~~~~~~~~~~~

.. automodule:: ax.core.experiment
    :members:
    :undoc-members:
    :show-inheritance:

`GeneratorRun`
~~~~~~~~~~~~~~

.. automodule:: ax.core.generator_run
    :members:
    :undoc-members:
    :show-inheritance:

`MapData`
~~~~~~~~~~~~~~

.. automodule:: ax.core.map_data
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

`MapMetric`
~~~~~~~~~~~~~~

.. automodule:: ax.core.map_metric
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

`Metric`
~~~~~~~~~~~~~~

.. automodule:: ax.core.metric
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

`MultiTypeExperiment`
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.multi_type_experiment
    :members:
    :undoc-members:
    :show-inheritance:

`Objective`
~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.objective
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

`Observation`
~~~~~~~~~~~~~~

.. automodule:: ax.core.observation
    :members:
    :undoc-members:
    :show-inheritance:

`OptimizationConfig`
~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.optimization_config
    :members:
    :undoc-members:
    :show-inheritance:

`OutcomeConstraint`
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.outcome_constraint
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

`Parameter`
~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.parameter
    :members:
    :undoc-members:
    :show-inheritance:

`ParameterConstraint`
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.parameter_constraint
    :members:
    :undoc-members:
    :show-inheritance:

`ParameterDistribution`
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.parameter_distribution
    :members:
    :undoc-members:
    :show-inheritance:

`RiskMeasure`
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.risk_measures
    :members:
    :undoc-members:
    :show-inheritance:

`Runner`
~~~~~~~~~~~~~~~~

.. automodule:: ax.core.runner
    :members:
    :undoc-members:
    :show-inheritance:

`SearchSpace`
~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.core.search_space
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

`Trial`
~~~~~~~~

.. automodule:: ax.core.trial
    :members:
    :undoc-members:
    :show-inheritance:


Core Types
----------

.. automodule:: ax.core.types
    :members:
    :undoc-members:
    :show-inheritance:


Core Utils
----------

.. automodule:: ax.core.utils
    :members:
    :undoc-members:
    :show-inheritance:
